@@ -36,5 +36,5 @@ register(
 
 register(
     id='MaxIndependentSet-v0',
-    entry_point='graph_envs.max_independent_set:MaxIndependentSetEnv',
+    entry_point='graph_envs.max_independent_set:MaxIndependentSet',
 )
\ No newline at end of file
